All of the people who have made at least one contribution to datamol.
Authors are sorted alphabetically.

* Cas
* DeepSource Bot
* DomInvivo
* Emmanuel Noutahi
* Hadrien Mary
* Honoré Hounwanou
* Ishan Kumar
* Julien Horwood
* Lu Zhu
* Matt
* Pakman450
* Saurav Maheshkar
* Therence1
* Valence-JonnyHsu
* deepsource-autofix[bot]
* michelml
* mike
